@@ -25,7 +25,7 @@ module Plugin::GUI::Cuscadable
         @unload_hook = plugin.onunload{
           notice "widget destroy triggered off detach plugin #{@plugin}. widget: #{self}"
           destroy } end end
-    self.class.regist(self) end
+    self.class.register(self) end
 
   # 次のインスタンスを返す。このインスタンスが最後だった場合は最初に戻る
   def next
@@ -44,6 +44,7 @@ module Plugin::GUI::Cuscadable
     values[index] end
 
   module ExtendedCuscadable
+    extend Gem::Deprecate
 
     # タブ _slug_ に対するインターフェイスを作成。
     # _slug_ に対応するタブがない場合は作成する。
@@ -70,9 +71,11 @@ module Plugin::GUI::Cuscadable
     # [tab] タブ
     # ==== Return
     # self
-    def regist(tab)
+    def register(tab)
       cuscaded[tab.slug] ||= tab
       self end
+    alias :regist :register
+    deprecate :regist, "register", 2016, 12
 
     # インスタンスの一覧を取得する
     # ==== Return
@@ -92,4 +95,3 @@ module Plugin::GUI::Cuscadable
   end
 
 end
-
